@@ -140,7 +140,7 @@ def spawn_cloud(name, digitalocean_token):
     print(ip_address, flush=True)
 
     print("spawning gaea..", flush=True)
-    root_ssh = digitalocean.get_ssh("root", ip_address)
+    root_ssh = digitalocean.get_ssh("root", ip_address, process_out(ip_address))
     root_ssh("adduser gaea --disabled-login --gecos gaea")
     root_ssh('echo "gaea  ALL=NOPASSWD: ALL" | tee -a /etc/sudoers.d/01_gaea')
 
@@ -149,32 +149,32 @@ def spawn_cloud(name, digitalocean_token):
     root_ssh(f"cp /root/.ssh/authorized_keys {gaea_ssh_dir}")
     root_ssh(f"chown gaea:gaea {gaea_ssh_dir} -R")
 
-    root_ssh("apt install fuse -y")
+    root_ssh("apt install fuse -y")  # TODO while loop
 
     print("spawning the understory..", flush=True)
     print("__file__:", __file__)
     digitalocean.scp("gaea", f"gaea@{ip_address}:")
-    gaea_ssh = digitalocean.get_ssh("gaea", ip_address)
+    gaea_ssh = digitalocean.get_ssh("gaea", ip_address, process_out(ip_address))
     gaea_ssh("chown gaea:gaea gaea")
     gaea_ssh("chmod u+x gaea")
-    gaea_ssh(f"./gaea setup {digitalocean_token}", process_out(ip_address))
+    gaea_ssh(f"./gaea setup {digitalocean_token}")
 
 
-# TODO XXX def spawn_local():
-# TODO XXX     # sh.sudo("bash", "spawn.sh")  # TODO FIXME
-# TODO XXX
-# TODO XXX     # sh.scp("-i", "gaea_key", "gaea", "gaea@localhost:")
-# TODO XXX
-# TODO XXX     # TODO sh bake
-# TODO XXX     def ssh(command):
-# TODO XXX         sh.ssh(
-# TODO XXX             "gaea@localhost", "-i", "gaea_key", command,
-# TODO XXX             _out=process_out("localhost")
-# TODO XXX         )
-# TODO XXX
-# TODO XXX     # ssh("chown gaea:gaea gaea")
-# TODO XXX     # ssh("chmod u+x gaea")
-# TODO XXX     ssh("./gaea setup")
+# def spawn_local():
+#     # sh.sudo("bash", "spawn.sh")  # TODO FIXME
+#
+#     # sh.scp("-i", "gaea_key", "gaea", "gaea@localhost:")
+#
+#     # TODO sh bake
+#     def ssh(command):
+#         sh.ssh(
+#             "gaea@localhost", "-i", "gaea_key", command,
+#             _out=process_out("localhost")
+#         )
+#
+#     # ssh("chown gaea:gaea gaea")
+#     # ssh("chmod u+x gaea")
+#     ssh("./gaea setup")
 
 
 def process_out(host):
@@ -252,7 +252,7 @@ def install_app(app, home_dir, github_token):
         sh.Command(f"{home_dir}/.local/bin/poetry")(
             "install",
             _cwd=working_dir / user / repo,
-            _env={},  # NOTE ensures VIRTUAL_ENV is absent
+            _env=dict(os.environ, VIRTUAL_ENV=""),
         )
         # XXX gh_prefix = f"https://api.github.com/repos/{app}/releases"
         # XXX gh_token_header = f"token {github_token}"
@@ -613,9 +613,10 @@ class Gaea:
     def mount_site(self, site, app):
         """Instruct Nginx to route requests for `site` to `app`."""
         if app not in get_statuses():
-            # XXX if site.startswith("dev."):
             if "#" in app:
-                self.run_development_app(app)
+                project, _, app = app.partition("#")
+                self.run_development_app(project, app)
+                app = f"{project}/{app}"
             else:
                 self.run_production_app(app)
         config = self.get_config()
@@ -629,11 +630,10 @@ class Gaea:
             )
         sh.sudo("supervisorctl", "restart", "nginx")
 
-    def run_development_app(self, app, workers=2):
+    def run_development_app(self, project, app, workers=2):
         """Instruct Supervisor to run given `app` using gunicorn."""
         supervisor = configparser.ConfigParser()
-        project, _, callable = app.partition("#")
-        name = callable.replace(":", "-")
+        name = app.replace(":", "-")
         app_dir = self.apps_dir / project / name
         app_dir.mkdir(parents=True, exist_ok=True)
         env_dir = sh.Command(f"{self.home_dir}/.local/bin/poetry")(
@@ -645,7 +645,7 @@ class Gaea:
         )
         dashed_project = project.replace("/", "-")
         command = (
-            f"{self.home_dir}/runinenv {env_dir} gunicorn {callable}"
+            f"{self.home_dir}/runinenv {env_dir} gunicorn {app}"
             f" -k gevent -w {workers} --bind unix:{app_dir}/app.sock"
         )
         supervisor[f"program:{dashed_project}-{name}"] = {
