@@ -20,7 +20,7 @@ app = web.application(
     },
     db=True,
     mounts=(web.framework.data_app, indieweb.indieauth.client.app),
-    wrappers=(indieweb.indieauth.client.wrap),
+    wrappers=(indieweb.indieauth.client.wrap,),
 )
 
 
@@ -31,7 +31,7 @@ def contextualize(handler, app):
     yield
 
 
-@app.route(r"")
+@app.control(r"")
 class Main:
     """Admin interface."""
 
@@ -126,7 +126,7 @@ class Main:
             raise web.Unauthorized("please sign in with your secret")
 
 
-@app.route(r"tokens/{service}")
+@app.control(r"tokens/{service}")
 class Token:
     """A token for a third-party service."""
 
@@ -142,7 +142,7 @@ class Token:
         raise web.SeeOther("/")
 
 
-@app.route(r"sites")
+@app.control(r"sites")
 class Websites:
     """Installed sites."""
 
@@ -155,7 +155,7 @@ class Websites:
         raise web.SeeOther("/")
 
 
-@app.route(r"sites/{site}")
+@app.control(r"sites/{site}")
 class Website:
     """Installed site."""
 
@@ -168,7 +168,7 @@ class Website:
         raise web.SeeOther("/")
 
 
-@app.route(r"sites/{site}/dns")
+@app.control(r"sites/{site}/dns")
 class WebsiteDNS:
     """Site A record."""
 
@@ -195,7 +195,7 @@ class WebsiteDNS:
         raise web.SeeOther("/")
 
 
-@app.route(r"sites/{site}/certificate")
+@app.control(r"sites/{site}/certificate")
 class WebsiteCertificate:
     """A site's certificate."""
 
@@ -248,7 +248,7 @@ class WebsiteCertificate:
         raise web.SeeOther("/")
 
 
-@app.route(r"sites/{site}/mount")
+@app.control(r"sites/{site}/mount")
 class WebsiteMount:
     """Site mount."""
 
@@ -259,7 +259,7 @@ class WebsiteMount:
         raise web.SeeOther("/")
 
 
-@app.route(r"apps")
+@app.control(r"apps")
 class Applications:
     """Installed applications."""
 
@@ -294,7 +294,7 @@ class Applications:
         # XXX       app_url, _cwd=tx.gaea.home_dir)
 
 
-@app.route(r"apps/{pkg}")
+@app.control(r"apps/{pkg}")
 class Package:
     """Installed application package."""
 
@@ -304,7 +304,7 @@ class Package:
         return "upgrading and restarting.."
 
 
-@app.route(r"apps/{app}")
+@app.control(r"apps/{app}")
 class Application:
     """Installed application."""
 
